# Citation

To cite pySWATPlus, use:

```tex
@misc{Salo_Llorente_2023,
  author    = {Saló, Joan and Llorente, Oliu},
  title     = {{pySWATPlus: A Python Interface for SWAT+ Model Calibration and Analysis}},
  year      = {2023},
  month     = dec,
  publisher = {Zenodo},
  version   = {0.1.0},
  doi       = {10.5281/zenodo.14889320},
  url       = {https://doi.org/10.5281/zenodo.14889320}
}
```

**Human-readable format:**  
Saló, J. & Llorente, O. (2023). pySWATPlus: A Python Interface for SWAT+ Model Calibration and Analysis (Version 0.1.0) [Computer software]. Zenodo. https://doi.org/10.5281/zenodo.14889320